@@ -12,8 +12,6 @@ urlpatterns = patterns("",
     url("^$", direct_to_template, {"template": "index.html"}, name="home"),
     # HOMEPAGE AS AN EDITABLE PAGE IN THE PAGE TREE
     #url("^$", "mezzanine.pages.views.page", {"slug": "/"}, name="home"),
-    # MEZZANINE'S URLS
-    ("^", include("mezzanine.urls")),
 )
 # NECESSARY for the DEBUG TOOLBAR pre 1.7
 if settings.DEBUG:
@@ -26,3 +24,9 @@ if settings.DEBUG:
 
 if settings.DEBUG:
     urlpatterns += staticfiles_urlpatterns()
+
+
+#Mezzanine if used as a catch-all must be the final include
+urlpatterns += patterns("",
+                        ("^", include("mezzanine.urls")),
+                        )
