@@ -1,8 +1,6 @@
 import os
+from subprocess import Popen, PIPE
 """uwsgi_portsniffer.py
-Use a uwsgi log file to find the bound uwsgi port
-Mostly useful for non-root users, as root can query the socket
-much easier.
 """
 
 def port_from_lsof(inifile):
